@@ -29,10 +29,11 @@ from valo_api.endpoints.mmr_history import (
     get_mmr_history_by_puuid,
     get_mmr_history_by_puuid_v1,
 )
+from valo_api.endpoints.raw import get_raw_data, get_raw_data_v1
 from valo_api.endpoints.status import get_status, get_status_v1
 from valo_api.endpoints.store_featured import get_store_featured, get_store_featured_v1
 from valo_api.endpoints.store_offers import get_store_offers, get_store_offers_v1
-from valo_api.endpoints.version_details import get_version_info, get_version_info_v1
+from valo_api.endpoints.version_info import get_version_info, get_version_info_v1
 from valo_api.endpoints.website import get_website, get_website_v1
 
 __all__ = [
@@ -69,4 +70,6 @@ __all__ = [
     "get_leaderboard_v1",
     "get_leaderboard_v2",
     "get_leaderboard",
+    "get_raw_data_v1",
+    "get_raw_data",
 ]
