@@ -1,6 +1,7 @@
 from typing import List, Union
 
 from valo_api.endpoints_config import EndpointsConfig
+from valo_api.exceptions.valo_api_exception import ValoAPIException
 from valo_api.responses.error_response import ErrorResponse
 from valo_api.responses.mmr_history import MMRHistoryPointV1
 from valo_api.utils.fetch_endpoint import fetch_endpoint
@@ -32,7 +33,7 @@ def get_mmr_history_by_name(
     response_data = response.json()
 
     if response.ok is False:
-        return ErrorResponse.from_dict(**response_data)
+        raise ValoAPIException(ErrorResponse.from_dict(**response_data))
 
     return [MMRHistoryPointV1.from_dict(**point) for point in response_data["data"]]
 
@@ -50,6 +51,6 @@ def get_mmr_history_by_puuid(
     response_data = response.json()
 
     if response.ok is False:
-        return ErrorResponse.from_dict(**response_data)
+        raise ValoAPIException(ErrorResponse.from_dict(**response_data))
 
     return [MMRHistoryPointV1.from_dict(**point) for point in response_data["data"]]
