@@ -1,6 +1,7 @@
 from typing import Union
 
 from valo_api.endpoints_config import EndpointsConfig
+from valo_api.exceptions.valo_api_exception import ValoAPIException
 from valo_api.responses.error_response import ErrorResponse
 from valo_api.responses.status import StatusV1
 from valo_api.utils.fetch_endpoint import fetch_endpoint
@@ -20,6 +21,6 @@ def get_status(version: str, region: str, **kwargs) -> Union[StatusV1, ErrorResp
     response_data = response.json()
 
     if response.ok is False:
-        return ErrorResponse.from_dict(**response_data)
+        raise ValoAPIException(ErrorResponse.from_dict(**response_data))
 
     return StatusV1.from_dict(**response_data["data"])
