@@ -13,16 +13,16 @@ class ValoAPIException(Exception):
         super().__init__(response)
 
     def __str__(self):
-        return self.response
+        return str(self.response)
 
     @property
     def status(self) -> Optional[int]:
         return self.response.status
 
     @property
-    def message(self) -> Optional[int]:
+    def message(self) -> Optional[str]:
         return self.response.message
 
     @property
-    def error(self) -> Optional[int]:
+    def error(self) -> Optional[str]:
         return self.response.error
